@@ -28,7 +28,10 @@ from collections import OrderedDict
 
 BSOFT_HOME = 'BSOFT_HOME'
 
+BSOFT = 'bsoft'
+
 # Supported Versions
+V2_0_7 = '2.0.7'
 V1_9_0 = '1.9.0'
 
 # Bfilter constants
@@ -49,4 +52,3 @@ COOR_DICT = OrderedDict([
              ("_x", "particle.x"),
              ("_y", "particle.y")
              ])
-
